@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized );
 
-our $VERSION = '1.809';
+our $VERSION = '1.811';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitSubroutinePrototypes)
@@ -396,6 +396,7 @@ sub new {
       $self{posix_exit} = 1 if ($_has_threads && $_tid);
       $self{posix_exit} = 1 if ($INC{'CGI.pm'} || $INC{'FCGI.pm'});
       $self{posix_exit} = 1 if ($INC{'Mojo/IOLoop.pm'} || $INC{'Tk.pm'});
+      $self{posix_exit} = 1 if ($INC{'Gearman/XS.pm'} || $INC{'Gearman/Util.pm'});
    }
 
    $self{flush_file}   ||= 0;
@@ -510,7 +511,7 @@ sub spawn {
    }
    elsif (defined $self->{input_data}) {
       my $_ref = ref $self->{input_data};
-      if ($_ref eq 'ARRAY' || $_ref eq 'GLOB' || $_ref =~ /^IO::/) {
+      if ($_ref eq 'ARRAY' || $_ref =~ /^(?:GLOB|FileHandle|IO::)/) {
          require MCE::Core::Input::Request
             unless $INC{'MCE/Core/Input/Request.pm'};
       }
@@ -914,7 +915,7 @@ sub run {
    elsif (defined $self->{input_data}) {
       my $_ref = ref $self->{input_data};
 
-      if ($_ref eq 'ARRAY') {                        # Array mode
+      if ($_ref eq 'ARRAY') {                         # Array mode
          $_run_mode   = 'array';
          $_input_data = $self->{input_data};
          $_input_file = $_input_glob = undef;
@@ -926,21 +927,21 @@ sub run {
             return $self->shutdown() if ($_auto_shutdown == 1);
          }
       }
-      elsif ($_ref eq 'GLOB' || $_ref =~ /^IO::/) {  # Glob mode
+      elsif ($_ref =~ /^(?:GLOB|FileHandle|IO::)/) {  # Glob mode
          $_run_mode   = 'glob';
          $_input_glob = $self->{input_data};
          $_input_data = $_input_file = undef;
          $_abort_msg  = 0; ## Flag: Has Data: No
          $_first_msg  = 1; ## Flag: Has Data: Yes
       }
-      elsif ($_ref eq 'CODE') {                      # Iterator mode
+      elsif ($_ref eq 'CODE') {                       # Iterator mode
          $_run_mode   = 'iterator';
          $_input_data = $self->{input_data};
          $_input_file = $_input_glob = undef;
          $_abort_msg  = 0; ## Flag: Has Data: No
          $_first_msg  = 1; ## Flag: Has Data: Yes
       }
-      elsif ($_ref eq '') {                          # File mode
+      elsif ($_ref eq '') {                           # File mode
          $_run_mode   = 'file';
          $_input_file = $self->{input_data};
          $_input_data = $_input_glob = undef;
@@ -951,7 +952,7 @@ sub run {
             return $self->shutdown() if ($_auto_shutdown == 1);
          }
       }
-      elsif ($_ref eq 'SCALAR') {                    # Memory mode
+      elsif ($_ref eq 'SCALAR') {                     # Memory mode
          $_run_mode   = 'memory';
          $_input_data = $_input_file = $_input_glob = undef;
          $_abort_msg  = length(${ $self->{input_data} }) + 1;
@@ -965,7 +966,7 @@ sub run {
          _croak('MCE::run: (input_data) is not valid');
       }
    }
-   else {                                            # Nodata mode
+   else {                                             # Nodata mode
       $_abort_msg = undef, $_run_mode = 'nodata';
    }
 
@@ -1093,7 +1094,10 @@ sub run {
       $self->shutdown();
    }
    elsif ($^S || $ENV{'PERL_IPERL_RUNNING'}) {
-      if (!$INC{'Mojo/IOLoop.pm'} && !$INC{'Tk.pm'}) {
+      if (
+         !$INC{'Gearman/XS.pm'} && !$INC{'Gearman/Util.pm'} &&
+         !$INC{'Mojo/IOLoop.pm'} && !$INC{'Tk.pm'}
+      ) {
          # running inside eval or IPerl, check stack trace
          my $_t = Carp::longmess(); $_t =~ s/\teval [^\n]+\n$//;
 
