@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized );
 
-our $VERSION = '1.809';
+our $VERSION = '1.811';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitSubroutinePrototypes)
@@ -151,7 +151,7 @@ sub run_file (@) {
 
    for my $_i ($_start_pos .. @_ - 1) {
       my $_r = ref $_[$_i];
-      if ($_r eq '' || $_r eq 'GLOB' || $_r eq 'SCALAR' || $_r =~ /^IO::/) {
+      if ($_r eq '' || $_r eq 'SCALAR' || $_r =~ /^(?:GLOB|FileHandle|IO::)/) {
          $_file = $_[$_i]; $_pos = $_i;
          last;
       }
@@ -163,7 +163,7 @@ sub run_file (@) {
       _croak("$_tag: ($_file) is not a plain file") unless (-f $_file);
       $_params->{$_pid}{_file} = $_file;
    }
-   elsif (ref $_file eq 'GLOB' || ref $_file eq 'SCALAR' || ref($_file) =~ /^IO::/) {
+   elsif (ref $_file eq 'SCALAR' || ref($_file) =~ /^(?:GLOB|FileHandle|IO::)/) {
       $_params->{$_pid}{_file} = $_file;
    }
    else {
@@ -311,7 +311,7 @@ sub run (@) {
    my $_input_data; my $_max_workers = $_def->{$_pkg}{MAX_WORKERS};
    my $_r = ref $_[0];
 
-   if ($_r eq 'ARRAY' || $_r eq 'GLOB' || $_r eq 'SCALAR' || $_r =~ /^IO::/) {
+   if ($_r eq 'ARRAY' || $_r eq 'SCALAR' || $_r =~ /^(?:GLOB|FileHandle|IO::)/) {
       $_input_data = shift if (@_ == 1);
    }
 
@@ -495,7 +495,7 @@ MCE::Flow - Parallel flow model for building creative applications
 
 =head1 VERSION
 
-This document describes MCE::Flow version 1.809
+This document describes MCE::Flow version 1.811
 
 =head1 DESCRIPTION
 
