@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized );
 
-our $VERSION = '1.809';
+our $VERSION = '1.811';
 
 ## no critic (Subroutines::ProhibitExplicitReturnUndef)
 ## no critic (TestingAndDebugging::ProhibitNoStrict)
@@ -874,7 +874,7 @@ sub _heap_insert_high {
             $_Q->{_asem} = 0;
          }
 
-         $_Q->{_nb_flag} = 1;
+         $_Q->{_nb_flag} = $_Q->_has_data() ? 1 : 0;
 
          return;
       },
@@ -1163,7 +1163,8 @@ sub _mce_m_dequeue_nb {
       return;
    }
    else {
-      $_Q->{_nb_flag} = 1;
+      $_Q->{_nb_flag} = $_Q->_has_data() ? 1 : 0;
+
       return (defined $_cnt && $_cnt ne '1')
          ? $_Q->_dequeue($_cnt) : $_Q->_dequeue();
    }
@@ -1637,7 +1638,7 @@ MCE::Queue - Hybrid (normal and priority) queues
 
 =head1 VERSION
 
-This document describes MCE::Queue version 1.809
+This document describes MCE::Queue version 1.811
 
 =head1 SYNOPSIS
 
